advertools Command Line Interface (CLI)
=======================================

Once you install advertools with ``python3 -m pip install advertools``, you
should have acess to the command line interface and run the available commands.

You just need Python3 installed, and you are good to go (no need for any Python
programming to use the CLI)

Run ``advertools --help`` or ``adv -h`` to get access to the documentation.

For specific documentation of a certain command run
``advertools <command> --help``

For example ``advertools sitemaps --help`` or ``adv crawl -h``

.. automodule:: advertools.cli.cli
   :members:
   :undoc-members:
   :show-inheritance:
